@@ -23,11 +23,23 @@
  +-------------------------------------------------------------------------+
 */
 
-define('REGEXP_SNMP_TRIM', '/(hex|counter(32|64)|gauge|gauge(32|64)|float|ipaddress|string|integer):/i');
+define('REGEXP_SNMP_TRIM', '/(hex|counter(32|64)|gauge|gauge(32|64)|float|ipaddress|string|integer):|(up|down)\(|\)$/i');
 
 define('SNMP_METHOD_PHP', 1);
 define('SNMP_METHOD_BINARY', 2);
 
+if (!defined('SNMP_STRING_OUTPUT_GUESS')) {
+	define('SNMP_STRING_OUTPUT_GUESS', 1);
+}
+
+if (!defined('SNMP_STRING_OUTPUT_ASCII')) {
+	define('SNMP_STRING_OUTPUT_ASCII', 2);
+}
+
+if (!defined('SNMP_STRING_OUTPUT_HEX')) {
+	define('SNMP_STRING_OUTPUT_HEX', 3);
+}
+
 global $banned_snmp_strings;
 $banned_snmp_strings = array('End of MIB', 'No Such', 'No more');
 
@@ -35,7 +47,10 @@ if (!class_exists('SNMP')) {
 	include_once($config['include_path'] . '/phpsnmp/classSNMP.php');
 }
                                 
-function cacti_snmp_session($hostname, $community, $version, $username, $password, $auth_proto, $priv_pass, $priv_proto, $context, $contextEngineID, $port = 161, $timeout = 500, $retries = 0, $max_oids = 10) {
+function cacti_snmp_session($hostname, $community, $version, $username, $password, 
+	$auth_proto, $priv_pass, $priv_proto, $context, $engineid, 
+	$port = 161, $timeout = 500, $retries = 0, $max_oids = 10) {
+
 	switch ($version) {
 		case '1': 
 			$version = SNMP::VERSION_1; 
@@ -58,6 +73,7 @@ function cacti_snmp_session($hostname, $community, $version, $username, $passwor
 		$session->oid_output_format = SNMP_OID_OUTPUT_NUMERIC;
 		$session->valueretrieval = SNMP_VALUE_LIBRARY;
 	}
+
 	$session->max_oids = $max_oids;
 
 	if (read_config_option('oid_increasing_check_disable') == 'on') {
@@ -76,7 +92,7 @@ function cacti_snmp_session($hostname, $community, $version, $username, $passwor
 	}
 	
 	try {
-		$session->setSecurity($sec_level, $auth_proto, $password, $priv_proto, $priv_pass, $context, $contextEngineID);
+		$session->setSecurity($sec_level, $auth_proto, $password, $priv_proto, $priv_pass, $context, $engineid);
 	} catch (Exception $e) {
 		return false;
 	}
@@ -85,29 +101,19 @@ function cacti_snmp_session($hostname, $community, $version, $username, $passwor
 }
 
 function cacti_snmp_get($hostname, $community, $oid, $version, $username, $password, 
-	$auth_proto, $priv_pass, $priv_proto, $context, $port = 161, $timeout = 500, 
-	$retries = 0, $environ = SNMP_POLLER, $contextEngineID = '') {
+	$auth_proto, $priv_pass, $priv_proto, $context, 
+	$port = 161, $timeout = 500, $retries = 0, $environ = SNMP_POLLER, 
+	$engineid = '', $value_output_format = SNMP_STRING_OUTPUT_GUESS) {
 
 	global $config, $snmp_error;
 
-	/* determine default retries */
-	if (($retries == 0) || (!is_numeric($retries))) {
-		$retries = read_config_option('snmp_retries');
-		if ($retries == '') $retries = 3;
-	}
+	$max_oids = 1;
 
-	/* do not attempt to poll invalid combinations */
-	if (($version == 0) || (!is_numeric($version)) ||
-		(!is_numeric($port)) ||
-		(!is_numeric($retries)) ||
-		(!is_numeric($timeout)) ||
-		(($community == '') && ($version != 3))
-		) {
+	if (!cacti_snmp_options_sanitize($version, $community, $port, $timeout, $retries, $max_oids)) {
 		return 'U';
 	}
 
-	if ((snmp_get_method($version) == SNMP_METHOD_PHP) &&
-		(!strlen($context) || ($version != 3))) {
+	if (snmp_get_method('get', $version, $context, $engineid, $value_output_format) == SNMP_METHOD_PHP) {
 		/* make sure snmp* is verbose so we can see what types of data
 		we are getting back */
 		snmp_set_quick_print(0);
@@ -135,9 +141,9 @@ function cacti_snmp_get($hostname, $community, $oid, $version, $username, $passw
 			cacti_log("WARNING: SNMP Error:'$snmp_error', Device:'$hostname', OID:'$oid'", false);
 			$snmp_value = 'U';
 		} else {
-			$snmp_value = format_snmp_string($snmp_value, false);
+			$snmp_value = format_snmp_string($snmp_value, false, $value_output_format);
 		}
-	}else {
+	} else {
 		$snmp_value = '';
 
 		/* net snmp want the timeout in seconds */
@@ -156,22 +162,22 @@ function cacti_snmp_get($hostname, $community, $oid, $version, $username, $passw
 				$sec_level = 'authPriv';
 			}
 
-			if (strlen($priv_pass)) {
+			if ($priv_pass != '') {
 				$priv_pass = '-X ' . snmp_escape_string($priv_pass) . ' -x ' . snmp_escape_string($priv_proto);
 			} else {
 				$priv_pass = '';
 			}
 
-			if (strlen($context)) {
+			if ($context != '') {
 				$context = '-n ' . snmp_escape_string($context);
 			} else {
 				$context = '';
 			}
 
-			if (strlen($contextEngineID)) {
-				$contextEngineID = '-e ' . snmp_escape_string($contextEngineID);
+			if ($engineid != '') {
+				$engineid = '-e ' . snmp_escape_string($engineid);
 			} else {
-				$contextEngineID = '';
+				$engineid = '';
 			}
 
 			$snmp_auth = trim('-u ' . snmp_escape_string($username) .
@@ -180,14 +186,14 @@ function cacti_snmp_get($hostname, $community, $oid, $version, $username, $passw
 				' -A ' . snmp_escape_string($password) .
 				' '    . $priv_pass .
 				' '    . $context . 
-				' '    . $contextEngineID); 
+				' '    . $engineid); 
 		}
 
 		/* no valid snmp version has been set, get out */
 		if (empty($snmp_auth)) { return; }
 
 		exec(cacti_escapeshellcmd(read_config_option('path_snmpget')) . 
-			' -O fntevU ' . $snmp_auth . 
+			' -O fntevU' . ($value_output_format == SNMP_STRING_OUTPUT_HEX ? 'x ':' ') . $snmp_auth . 
 			' -v ' . $version . 
 			' -t ' . $timeout . 
 			' -r ' . $retries . 
@@ -203,7 +209,7 @@ function cacti_snmp_get($hostname, $community, $oid, $version, $username, $passw
 			cacti_log("WARNING: SNMP Error:'Timeout', Device:'$hostname', OID:'$oid'", false);
 			$snmp_value = 'U';
 		} else {
-			$snmp_value = format_snmp_string($snmp_value, false);
+			$snmp_value = format_snmp_string($snmp_value, false, $value_output_format);
 		}
 	}
 
@@ -211,29 +217,19 @@ function cacti_snmp_get($hostname, $community, $oid, $version, $username, $passw
 }
 
 function cacti_snmp_get_raw($hostname, $community, $oid, $version, $username, $password, 
-	$auth_proto, $priv_pass, $priv_proto, $context, $port = 161, $timeout = 500, 
-	$retries = 0, $environ = SNMP_POLLER, $contextEngineID = '') {
+	$auth_proto, $priv_pass, $priv_proto, $context, 
+	$port = 161, $timeout = 500, $retries = 0, $environ = SNMP_POLLER, 
+	$engineid = '', $value_output_format = SNMP_STRING_OUTPUT_GUESS) {
 
 	global $config, $snmp_error;
 
-	/* determine default retries */
-	if (($retries == 0) || (!is_numeric($retries))) {
-		$retries = read_config_option('snmp_retries');
-		if ($retries == '') $retries = 3;
-	}
+	$max_oids = 1;
 
-	/* do not attempt to poll invalid combinations */
-	if (($version == 0) || (!is_numeric($version)) ||
-		(!is_numeric($port)) ||
-		(!is_numeric($retries)) ||
-		(!is_numeric($timeout)) ||
-		(($community == '') && ($version != 3))
-		) {
+	if (!cacti_snmp_options_sanitize($version, $community, $port, $timeout, $retries, $max_oids)) {
 		return 'U';
 	}
 
-	if ((snmp_get_method($version) == SNMP_METHOD_PHP) &&
-		(!strlen($context) || ($version != 3))) {
+	if (snmp_get_method('get', $version, $context, $engineid, $value_output_format) == SNMP_METHOD_PHP) {
 		/* make sure snmp* is verbose so we can see what types of data
 		we are getting back */
 		snmp_set_quick_print(0);
@@ -261,7 +257,7 @@ function cacti_snmp_get_raw($hostname, $community, $oid, $version, $username, $p
 			cacti_log("WARNING: SNMP Error:'$snmp_error', Device:'$hostname', OID:'$oid'", false);
 			$snmp_value = 'U';
 		}
-	}else {
+	} else {
 		$snmp_value = '';
 
 		/* net snmp want the timeout in seconds */
@@ -280,22 +276,22 @@ function cacti_snmp_get_raw($hostname, $community, $oid, $version, $username, $p
 				$sec_level = 'authPriv';
 			}
 
-			if (strlen($priv_pass)) {
+			if ($priv_pass != '') {
 				$priv_pass = '-X ' . snmp_escape_string($priv_pass) . ' -x ' . snmp_escape_string($priv_proto);
 			} else {
 				$priv_pass = '';
 			}
 
-			if (strlen($context)) {
+			if ($context != '') {
 				$context = '-n ' . snmp_escape_string($context);
 			} else {
 				$context = '';
 			}
 
-			if (strlen($contextEngineID)) {
-				$contextEngineID = '-e ' . snmp_escape_string($contextEngineID);
+			if ($engineid != '') {
+				$engineid = '-e ' . snmp_escape_string($engineid);
 			} else {
-				$contextEngineID = '';
+				$engineid = '';
 			}
 
 			$snmp_auth = trim('-u ' . snmp_escape_string($username) .
@@ -304,14 +300,14 @@ function cacti_snmp_get_raw($hostname, $community, $oid, $version, $username, $p
 				' -A ' . snmp_escape_string($password) .
 				' '    . $priv_pass .
 				' '    . $context . 
-				' '    . $contextEngineID); 
+				' '    . $engineid); 
 		}
 
 		/* no valid snmp version has been set, get out */
 		if (empty($snmp_auth)) { return; }
 
 		exec(cacti_escapeshellcmd(read_config_option('path_snmpget')) . 
-			' -O fntev ' . $snmp_auth . 
+			' -O fntev' . ($value_output_format == SNMP_STRING_OUTPUT_HEX ? 'x ':' ') . $snmp_auth . 
 			' -v ' . $version . 
 			' -t ' . $timeout . 
 			' -r ' . $retries . 
@@ -333,25 +329,19 @@ function cacti_snmp_get_raw($hostname, $community, $oid, $version, $username, $p
 }
 
 function cacti_snmp_getnext($hostname, $community, $oid, $version, $username, $password, 
-	$auth_proto, $priv_pass, $priv_proto, $context, $port = 161, $timeout = 500, 
-	$retries = 0, $environ = SNMP_POLLER, $contextEngineID = '') {
+	$auth_proto, $priv_pass, $priv_proto, $context, 
+	$port = 161, $timeout = 500, $retries = 0, $environ = SNMP_POLLER, 
+	$engineid = '', $value_output_format = SNMP_STRING_OUTPUT_GUESS) {
 
 	global $config, $snmp_error;
 
-	/* determine default retries */
-	if (($retries == 0) || (!is_numeric($retries))) {
-		$retries = read_config_option('snmp_retries');
-		if ($retries == '') $retries = 3;
-	}
+	$max_oids = 1;
 
-	/* do not attempt to poll invalid combinations */
-	if (($version == 0) || (!is_numeric($version)) || (!is_numeric($port)) || (!is_numeric($retries)) ||
-		(!is_numeric($timeout)) || (($community == '') && ($version != 3))) {
+	if (!cacti_snmp_options_sanitize($version, $community, $port, $timeout, $retries, $max_oids)) {
 		return 'U';
 	}
 
-	if ((snmp_get_method($version) == SNMP_METHOD_PHP) &&
-		(!strlen($context) || ($version != 3))) {
+	if (snmp_get_method('getnext', $version, $context, $engineid, $value_output_format) == SNMP_METHOD_PHP) {
 		/* make sure snmp* is verbose so we can see what types of data
 		we are getting back */
 		snmp_set_quick_print(0);
@@ -375,7 +365,7 @@ function cacti_snmp_getnext($hostname, $community, $oid, $version, $username, $p
 			cacti_log("WARNING: SNMP Error:'$snmp_error', Device:'$hostname', OID:'$oid'", false);
 			$snmp_value = 'U';
 		} else {
-			$snmp_value = format_snmp_string($snmp_value, false);
+			$snmp_value = format_snmp_string($snmp_value, false, $value_output_format);
 		}
 	} else {
 		$snmp_value = '';
@@ -396,22 +386,22 @@ function cacti_snmp_getnext($hostname, $community, $oid, $version, $username, $p
 				$sec_level = 'authPriv';
 			}
 
-			if (strlen($priv_pass)) {
+			if ($priv_pass != '') {
 				$priv_pass = '-X ' . snmp_escape_string($priv_pass) . ' -x ' . snmp_escape_string($priv_proto);
 			} else {
 				$priv_pass = '';
 			}
 
-			if (strlen($context)) {
+			if ($context != '') {
 				$context = '-n ' . snmp_escape_string($context);
 			} else {
 				$context = '';
 			}
 
-			if (strlen($contextEngineID)) {
-				$contextEngineID = '-e ' . snmp_escape_string($contextEngineID);
+			if ($engineid != '') {
+				$engineid = '-e ' . snmp_escape_string($engineid);
 			} else {
-				$contextEngineID = '';
+				$engineid = '';
 			}
 
 			$snmp_auth = trim('-u ' . snmp_escape_string($username) .
@@ -420,7 +410,7 @@ function cacti_snmp_getnext($hostname, $community, $oid, $version, $username, $p
 				' -A ' . snmp_escape_string($password) .
 				' '    . $priv_pass .
 				' '    . $context . 
-				' '    . $contextEngineID); 
+				' '    . $engineid); 
 		}
 
 		/* no valid snmp version has been set, get out */
@@ -429,7 +419,7 @@ function cacti_snmp_getnext($hostname, $community, $oid, $version, $username, $p
 		}
 
 		exec(cacti_escapeshellcmd(read_config_option('path_snmpgetnext')) . 
-			' -O fntevU ' . $snmp_auth . 
+			' -O fntevU' . ($value_output_format == SNMP_STRING_OUTPUT_HEX ? 'x ':' ') . $snmp_auth . 
 			' -v ' . $version . 
 			' -t ' . $timeout .
 			' -r ' . $retries . 
@@ -446,18 +436,23 @@ function cacti_snmp_getnext($hostname, $community, $oid, $version, $username, $p
 		}
 
 		/* strip out non-snmp data */
-		$snmp_value = format_snmp_string($snmp_value, false);
+		$snmp_value = format_snmp_string($snmp_value, false, $value_output_format);
 	}
 
 	return $snmp_value;
 }
 
-function cacti_snmp_session_walk($session, $oid, $dummy = false, $max_repetitions = NULL, $non_repeaters = NULL) {
+function cacti_snmp_session_walk($session, $oid, $dummy = false, $max_repetitions = NULL, 
+	$non_repeaters = NULL, $value_output_format = SNMP_STRING_OUTPUT_GUESS) {
+
 	$info = $session->info;
 	if (is_array($oid) && sizeof($oid) == 0) {
 		cacti_log('Empty OID!', false);
 		return array();
 	}
+
+	$session->value_output_format = $value_output_format;
+
 	if ($non_repeaters === NULL)
 		$non_repeaters = 0;
 	if ($max_repetitions === NULL)
@@ -473,8 +468,10 @@ function cacti_snmp_session_walk($session, $oid, $dummy = false, $max_repetition
 	}
 
 	if ($out === false) {
-		if($oid == '.1.3.6.1.2.1.47.1.1.1.1.2' || $oid == '1.3.6.1.4.1.9.9.68.1.2.2.1.2' || 
-			$oid == '.1.3.6.1.4.1.9.9.46.1.6.1.1.5' || $oid == '.1.3.6.1.4.1.9.9.46.1.6.1.1.14' ||
+		if ($oid == '.1.3.6.1.2.1.47.1.1.1.1.2' || 
+			$oid == '.1.3.6.1.4.1.9.9.68.1.2.2.1.2' || 
+			$oid == '.1.3.6.1.4.1.9.9.46.1.6.1.1.5' || 
+			$oid == '.1.3.6.1.4.1.9.9.46.1.6.1.1.14' ||
 			$oid == '.1.3.6.1.4.1.9.9.23.1.2.1.1.6') {
 			/* do nothing */
 		} elseif ($session->getErrno() == SNMP::ERRNO_TIMEOUT) {
@@ -486,7 +483,7 @@ function cacti_snmp_session_walk($session, $oid, $dummy = false, $max_repetition
 
 	if (sizeof($out)) {
 		foreach($out as $oid => $value){
-			$out[$oid] = format_snmp_string($value, false);
+			$out[$oid] = format_snmp_string($value, false, $value_output_format);
 		}
 	}
 
@@ -495,6 +492,7 @@ function cacti_snmp_session_walk($session, $oid, $dummy = false, $max_repetition
 
 function cacti_snmp_session_get($session, $oid) {
 	$info = $session->info;
+
 	if (is_array($oid) && sizeof($oid) == 0) {
 		cacti_log('Empty OID!', false);
 		return array();
@@ -562,8 +560,10 @@ function cacti_snmp_session_getnext($session, $oid) {
 	return $out;
 }
 
-function cacti_snmp_walk($hostname, $community, $oid, $version, $username, $password, $auth_proto, $priv_pass, 
-	$priv_proto, $context, $port = 161, $timeout = 500, $retries = 0, $max_oids = 10, $environ = SNMP_POLLER, $contextEngineID = '') {
+function cacti_snmp_walk($hostname, $community, $oid, $version, $username, $password, 
+	$auth_proto, $priv_pass, $priv_proto, $context, 
+	$port = 161, $timeout = 500, $retries = 0, $max_oids = 10, $environ = SNMP_POLLER, 
+	$engineid = '', $value_output_format = SNMP_STRING_OUTPUT_GUESS) {
 
 	global $config, $banned_snmp_strings, $snmp_error;
 
@@ -572,37 +572,13 @@ function cacti_snmp_walk($hostname, $community, $oid, $version, $username, $pass
 	$snmp_array        = array();
 	$temp_array        = array();
 
-	/* determine default retries */
-	if (($retries == 0) || (!is_numeric($retries))) {
-		$retries = read_config_option('snmp_retries');
-		if ($retries == '') $retries = 3;
-	}
-
-	/* determine default max_oids */
-	if (($max_oids == 0) || (!is_numeric($max_oids))) {
-		$max_oids = read_config_option('max_get_size');
-
-		if ($max_oids == '') $max_oids = 10;
-	}
-
-	/* do not attempt to poll invalid combinations */
-	if (($version == 0) || (!is_numeric($version)) ||
-		(!is_numeric($max_oids)) ||
-		(!is_numeric($port)) ||
-		(!is_numeric($retries)) ||
-		(!is_numeric($timeout)) ||
-		(($community == '') && ($version != 3))
-		) {
+	if (!cacti_snmp_options_sanitize($version, $community, $port, $timeout, $retries, $max_oids)) {
 		return array();
 	}
 
 	$path_snmpbulkwalk = read_config_option('path_snmpbulkwalk');
 
-	if ((snmp_get_method($version) == SNMP_METHOD_PHP) &&
-		(!strlen($context) || ($version != 3)) &&
-		(($version == 1) ||
-		(version_compare(phpversion(), '5.1') >= 0) ||
-		(!file_exists($path_snmpbulkwalk)))) {
+	if (snmp_get_method('walk', $version, $context, $engineid, $value_output_format) == SNMP_METHOD_PHP) {
 		/* make sure snmp* is verbose so we can see what types of data
 		we are getting back */
 
@@ -633,8 +609,10 @@ function cacti_snmp_walk($hostname, $community, $oid, $version, $username, $pass
 		if ($temp_array === false) {
 			if ($temp_array === false) {
 				cacti_log("WARNING: SNMP Error:'$snmp_error', Device:'$hostname', OID:'$oid'", false);
-			} elseif ($oid == '.1.3.6.1.2.1.47.1.1.1.1.2' || $oid == '1.3.6.1.4.1.9.9.68.1.2.2.1.2' ||
-				$oid == '.1.3.6.1.4.1.9.9.46.1.6.1.1.5' || $oid == '.1.3.6.1.4.1.9.9.46.1.6.1.1.14' ||
+			} elseif ($oid == '.1.3.6.1.2.1.47.1.1.1.1.2' || 
+				$oid == '.1.3.6.1.4.1.9.9.68.1.2.2.1.2' ||
+				$oid == '.1.3.6.1.4.1.9.9.46.1.6.1.1.5' || 
+				$oid == '.1.3.6.1.4.1.9.9.46.1.6.1.1.14' ||
 				$oid == '.1.3.6.1.4.1.9.9.23.1.2.1.1.6') {
 				/* do nothing */
 			} else {
@@ -657,7 +635,7 @@ function cacti_snmp_walk($hostname, $community, $oid, $version, $username, $pass
 			for (reset($temp_array); $i = key($temp_array); next($temp_array)) {
 				if ($temp_array[$i] != 'NULL') {
 					$snmp_array[$o]['oid'] = preg_replace('/^\./', '', $i);
-					$snmp_array[$o]['value'] = format_snmp_string($temp_array[$i], $snmp_oid_included);
+					$snmp_array[$o]['value'] = format_snmp_string($temp_array[$i], $snmp_oid_included, $value_output_format);
 				}
 				$o++;
 			}
@@ -679,22 +657,22 @@ function cacti_snmp_walk($hostname, $community, $oid, $version, $username, $pass
 				$sec_level = 'authPriv';
 			}
 
-			if (strlen($priv_pass)) {
+			if ($priv_pass != '') {
 				$priv_pass = '-X ' . snmp_escape_string($priv_pass) . ' -x ' . snmp_escape_string($priv_proto);
 			} else {
 				$priv_pass = '';
 			}
 
-			if (strlen($context)) {
+			if ($context != '') {
 				$context = '-n ' . snmp_escape_string($context);
 			} else {
 				$context = '';
 			}
 
-			if (strlen($contextEngineID)) {
-				$contextEngineID = '-e ' . snmp_escape_string($contextEngineID);
+			if ($engineid != '') {
+				$engineid = '-e ' . snmp_escape_string($engineid);
 			} else {
-				$contextEngineID = '';
+				$engineid = '';
 			}
 
 			$snmp_auth = trim('-u ' . snmp_escape_string($username) .
@@ -703,7 +681,7 @@ function cacti_snmp_walk($hostname, $community, $oid, $version, $username, $pass
 				' -A ' . snmp_escape_string($password) .
 				' '    . $priv_pass .
 				' '    . $context .
-				' '    . $contextEngineID);
+				' '    . $engineid);
 		}
 
 		if (read_config_option('oid_increasing_check_disable') == 'on') {
@@ -714,7 +692,7 @@ function cacti_snmp_walk($hostname, $community, $oid, $version, $username, $pass
 
 		if (file_exists($path_snmpbulkwalk) && ($version > 1) && ($max_oids > 1)) {
 			$temp_array = exec_into_array(cacti_escapeshellcmd($path_snmpbulkwalk) . 
-				' -O QnU ' . $snmp_auth . 
+				' -O QnU'  . ($value_output_format == SNMP_STRING_OUTPUT_HEX ? 'x ':' ') . $snmp_auth . 
 				' -v '     . $version .
 				' -t '     . $timeout . 
 				' -r '     . $retries . 
@@ -724,7 +702,7 @@ function cacti_snmp_walk($hostname, $community, $oid, $version, $username, $pass
 				cacti_escapeshellarg($oid));
 		} else {
 			$temp_array = exec_into_array(cacti_escapeshellcmd(read_config_option('path_snmpwalk')) . 
-				' -O QnU ' . $snmp_auth . 
+				' -O QnU ' . ($value_output_format == SNMP_STRING_OUTPUT_HEX ? 'x ':' ') . $snmp_auth . 
 				' -v '     . $version . 
 				' -t '     . $timeout .
 				' -r '     . $retries . 
@@ -741,7 +719,7 @@ function cacti_snmp_walk($hostname, $community, $oid, $version, $username, $pass
 		if (is_array($temp_array) && sizeof($temp_array)) {
 			foreach($temp_array as $key => $value) {
 				foreach($banned_snmp_strings as $item) {
-					if(strstr($value, $item) != '') {
+					if (strstr($value, $item) != '') {
 						unset($temp_array[$key]);
 						continue 2;
 					}
@@ -752,7 +730,7 @@ function cacti_snmp_walk($hostname, $community, $oid, $version, $username, $pass
 			foreach($temp_array as $index => $value) {
 				if (preg_match('/(.*) =.*/', $value)) {
 					$snmp_array[$i]['oid']   = trim(preg_replace('/(.*) =.*/', "\\1", $value));
-					$snmp_array[$i]['value'] = format_snmp_string($value, true);
+					$snmp_array[$i]['value'] = format_snmp_string($value, true, $value_output_format);
 					$i++;
 				} else {
 					$snmp_array[$i-1]['value'] .= $value;
@@ -764,7 +742,7 @@ function cacti_snmp_walk($hostname, $community, $oid, $version, $username, $pass
 	return $snmp_array;
 }
 
-function format_snmp_string($string, $snmp_oid_included) {
+function format_snmp_string($string, $snmp_oid_included, $value_output_format = SNMP_STRING_OUTPUT_GUESS) {
 	global $banned_snmp_strings;
 
 	$string = preg_replace(REGEXP_SNMP_TRIM, '', trim($string));
@@ -772,14 +750,15 @@ function format_snmp_string($string, $snmp_oid_included) {
 	if ($snmp_oid_included) {
 		/* strip off all leading junk (the oid and stuff) */
 		$string_array = explode('=', $string);
+
 		if (sizeof($string_array) == 1) {
 			/* trim excess first */
 			$string = trim($string);
-		}else if ((substr($string, 0, 1) == '.') || (strpos($string, '::') !== false)) {
+		} elseif ((substr($string, 0, 1) == '.') || (strpos($string, '::') !== false)) {
 			/* drop the OID from the array */
 			array_shift($string_array);
 			$string = trim(implode('=', $string_array));
-		}else {
+		} else {
 			$string = trim(implode('=', $string_array));
 		}
 	} else {
@@ -797,13 +776,7 @@ function format_snmp_string($string, $snmp_oid_included) {
 	}
 
 	/* remove ALL quotes, and other special delimiters */
-	$string = str_replace('"', '', $string);
-	$string = str_replace("'", '', $string);
-	$string = str_replace('>', '', $string);
-	$string = str_replace('<', '', $string);
-	$string = str_replace("\\", '', $string);
-	$string = str_replace("\n", ' ', $string);
-	$string = str_replace("\r", ' ', $string);
+	$string = str_replace(array('"', "'", '>', '<', "\\", "\n", "\r"), '', $string);
 
 	/* account for invalid MIB files */
 	if (strpos($string, 'Wrong Type') !== false) {
@@ -815,16 +788,21 @@ function format_snmp_string($string, $snmp_oid_included) {
 		}
 	}
 
-	/* Remove invalid chars */
-	$k = strlen($string);
-	for ($i=0; $i < $k; $i++) {
-		if ((ord($string[$i]) <= 31) || (ord($string[$i]) >= 127)) {
-			$string[$i] = ' ';
+	/* Remove invalid chars, if the string output is to be numeric */
+	if ($value_output_format == SNMP_STRING_OUTPUT_GUESS) {
+		$k = strlen($string);
+		for ($i=0; $i < $k; $i++) {
+			if ((ord($string[$i]) <= 31) || (ord($string[$i]) >= 127)) {
+				$string[$i] = ' ';
+			}
 		}
 	}
+
+	/* Trim the string of trailing and leading spaces */
 	$string = trim($string);
 
-	if (is_hex_string($string)) {
+	/* convert hex strings to numeric values */
+	if (is_hex_string($string) && $value_output_format == SNMP_VALUE_NUMERIC) {
 		$output = '';
 		$parts  = explode(' ', $string);
 
@@ -845,11 +823,8 @@ function format_snmp_string($string, $snmp_oid_included) {
 		$string = preg_replace('/hex- ?/i', '', $string);
 
 		/* normalize some forms */
-		$string = str_replace(' ', ':', $string);
-		$string = str_replace('-', ':', $string);
-		$string = str_replace('.', ':', $string);
-
-		$parts = explode(':', $string);
+		$string = str_replace(array(' ', '-', '.'), ':', $string);
+		$parts  = explode(':', $string);
 
 		if (is_mac_address($string)) {
 			$mac = true;
@@ -860,9 +835,12 @@ function format_snmp_string($string, $snmp_oid_included) {
 		/* convert the hex string into an ascii string */
 		foreach($parts as $part) {
 			if ($mac == false) {
-				if ($part == '00') break;
-
-				$output .= chr(hexdec($part));
+				$output .= ($output != '' ? ':' : '');
+				if ($part == '00') {
+					$output .= '00';
+				} else  {
+					$output .= str_pad($part, 2, '0', STR_PAD_LEFT);
+				}
 			} else {
 				$output .= ($output != '' ? ':' : '') . $part;
 			}
@@ -925,23 +903,53 @@ function snmp_escape_string($string) {
 	return SNMP_ESCAPE_CHARACTER . $string . SNMP_ESCAPE_CHARACTER;
 }
 
-function snmp_get_method($version = 1) {
-	if ((function_exists('snmpget')) && ($version == 1)) {
-		return SNMP_METHOD_PHP;
-	}else if ((function_exists('snmp2_get')) && ($version == 2)) {
-		return SNMP_METHOD_PHP;
-	}else if ((function_exists('snmp3_get')) && ($version == 3)) {
-		return SNMP_METHOD_PHP;
-	}else if ((($version == 2) || ($version == 3)) && (file_exists(read_config_option('path_snmpget')))) {
+function snmp_get_method($type = 'walk', $version = 1, $context = '', $engineid = '', 
+	$value_output_format = SNMP_STRING_OUTPUT_GUESS) {
+
+	if ($value_output_format == SNMP_STRING_OUTPUT_HEX) {
 		return SNMP_METHOD_BINARY;
-	}else if (function_exists('snmpget')) {
-		/* last resort (hopefully it isn't a 64-bit result) */
-		return SNMP_METHOD_PHP;
-	}else if (file_exists(read_config_option('path_snmpget'))) {
+	} elseif ($version == 3 && $context != '') {
 		return SNMP_METHOD_BINARY;
+	} elseif ($version == 3 && $engineid != '') {
+		return SNMP_METHOD_BINARY;
+	} elseif ($type == 'walk' && file_exists('path_snmpbulkwalk')) {
+		return SNMP_METHOD_BINARY;
+	} elseif (function_exists('snmpget') && $version == 1) {
+		return SNMP_METHOD_PHP;
+	} elseif (function_exists('snmp2_get') && $version == 2) {
+		return SNMP_METHOD_PHP;
+	} elseif (function_exists('snmp3_get') && $version == 3) {
+		return SNMP_METHOD_PHP;
 	} else {
-		/* looks like snmp is broken */
 		return SNMP_METHOD_BINARY;
 	}
 }
 
+function cacti_snmp_options_sanitize($version, $community, &$port, &$timeout, &$retries, &$max_oids) {
+	/* determine default retries */
+	if (($retries == 0) || (!is_numeric($retries))) {
+		$retries = read_config_option('snmp_retries');
+		if ($retries == '') $retries = 3;
+	}
+
+	/* determine default max_oids */
+	if (($max_oids == 0) || (!is_numeric($max_oids))) {
+		$max_oids = read_config_option('max_get_size');
+
+		if ($max_oids == '') $max_oids = 10;
+	}
+
+	/* do not attempt to poll invalid combinations */
+	if (($version == 0) || (!is_numeric($version)) ||
+		(!is_numeric($max_oids)) ||
+		(!is_numeric($port)) ||
+		(!is_numeric($retries)) ||
+		(!is_numeric($timeout)) ||
+		(($community == '') && ($version != 3))
+		) {
+		return false;
+	}
+
+	return true;
+}
+
